#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-hint
version:              0.1
visibility:           public
id:                   type-hint-0.1-CEVOa3UF09yBSz3YdyZSKB
key:                  type-hint-0.1-CEVOa3UF09yBSz3YdyZSKB
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/type-hint
synopsis:             Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.

category:             Phantom Types
abi:                  23ccddab8fab783bb7c8e2f42d45ca7d
exposed:              True
exposed-modules:      Type.Hint
import-dirs:          /usr/lib/ghc-8.10.5/site-local/type-hint-0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/type-hint-0.1
hs-libraries:         HStype-hint-0.1-CEVOa3UF09yBSz3YdyZSKB
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html:         /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

